##  Track KPIs in the Architecture Executive Dashboard
Get a high-level, KPI-driven overview of your organization's IT landscape. You can configure the dashboard to display up to four key performance indicators for each use case. Use drilldowns to explore performance metrics at multiple levels.
Learn more in [Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD "The architecture executive dashboard provides essential KPIs related to the organization’s IT landscape, enabling informed, data-driven decision-making through valuable insights.").
Key KPIs for application modernization:
  * **Application modernization (TIME)** : Track the number of applications classified as "Invest" in the TIME framework to identify modernization candidates and prioritize transformation efforts.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiocc8535423fad40328a27ee03c6f3df6c_LowRes.png)
  * **Cloud migration (by functional fit or business criticality):** Assess which applications are already in the cloud and evaluate their functional fit and business criticality. Combine these insights with the 6R framework to monitor and report your cloud transformation progress.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiod6322026c07c476ba4ace0de931a07c9_LowRes.png)
